@@ -155,7 +155,7 @@ class Disclosure(Mongo):
         unknown = {}
         for pid in responses:
             r = responses[pid]
-            if int(pid) not in people:
+            if pid and int(pid) not in people:
                 unknown[pid] = r
         return unknown
 
@@ -248,12 +248,15 @@ class Disclosure(Mongo):
     def prepareUser(self, g, p=None):
         """Prepare a user record for the database."""
         # get person id
+        emplid = None
         pid = None
         if p:
             pid = str(p['id'])
+            emplid = p['emplid']
 
         user = {
             'email': g['primaryEmail'],
+            'emplid': emplid,
             'family_name': g['name']['familyName'],
             'given_name': g['name']['givenName'],
             'hd': 'broadinstitute.org',
